@@ -27,12 +27,13 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-document.h 5428 2007-01-08 22:02:42Z pborelli $
+ * $Id: gedit-document.h 6275 2008-05-10 09:38:26Z pborelli $
  */
  
 #ifndef __GEDIT_DOCUMENT_H__
 #define __GEDIT_DOCUMENT_H__
 
+#include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <gtksourceview/gtksourcebuffer.h>
 #include <libgnomevfs/gnome-vfs.h>
@@ -46,7 +47,6 @@ G_BEGIN_DECLS
  */
 #define GEDIT_TYPE_DOCUMENT              (gedit_document_get_type())
 #define GEDIT_DOCUMENT(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_DOCUMENT, GeditDocument))
-#define GEDIT_DOCUMENT_CONST(obj)        (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_DOCUMENT, GeditDocument const))
 #define GEDIT_DOCUMENT_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GEDIT_TYPE_DOCUMENT, GeditDocumentClass))
 #define GEDIT_IS_DOCUMENT(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GEDIT_TYPE_DOCUMENT))
 #define GEDIT_IS_DOCUMENT_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GEDIT_TYPE_DOCUMENT))
@@ -60,6 +60,19 @@ typedef enum
 
 } GeditSearchFlags;
 
+/**
+ * GeditDocumentSaveFlags:
+ * @GEDIT_DOCUMENT_SAVE_IGNORE_MTIME: save file despite external modifications.
+ * @GEDIT_DOCUMENT_SAVE_IGNORE_BACKUP: write the file directly without attempting to backup.
+ * @GEDIT_DOCUMENT_SAVE_PRESERVE_BACKUP: preserve previous backup file, needed to support autosaving.
+ */
+typedef enum
+{
+	GEDIT_DOCUMENT_SAVE_IGNORE_MTIME 	= 1 << 0,
+	GEDIT_DOCUMENT_SAVE_IGNORE_BACKUP	= 1 << 1,
+	GEDIT_DOCUMENT_SAVE_PRESERVE_BACKUP	= 1 << 2
+} GeditDocumentSaveFlags;
+
 /* Private structure type */
 typedef struct _GeditDocumentPrivate    GeditDocumentPrivate;
 
@@ -90,6 +103,12 @@ struct _GeditDocumentClass
 	void (* cursor_moved)		(GeditDocument    *document);
 
 	/* Document load */
+	void (* load)			(GeditDocument       *document,
+					 const gchar         *uri,
+					 const GeditEncoding *encoding,
+					 gint                 line_pos,
+					 gboolean             create);
+
 	void (* loading)		(GeditDocument    *document,
 					 GnomeVFSFileSize  size,
 					 GnomeVFSFileSize  total_size);
@@ -98,6 +117,11 @@ struct _GeditDocumentClass
 					 const GError     *error);
 
 	/* Document save */
+	void (* save)			(GeditDocument          *document,
+					 const gchar            *uri,
+					 const GeditEncoding    *encoding,
+					 GeditDocumentSaveFlags  flags);
+
 	void (* saving)			(GeditDocument    *document,
 					 GnomeVFSFileSize  size,
 					 GnomeVFSFileSize  total_size);
@@ -112,19 +136,6 @@ struct _GeditDocumentClass
 };
 
 
-typedef enum
-{
-	/* save file despite external modifications */
-	GEDIT_DOCUMENT_SAVE_IGNORE_MTIME 	= 1 << 0,
-
-	/* write the file directly without attempting to backup */
-	GEDIT_DOCUMENT_SAVE_IGNORE_BACKUP	= 1 << 1,
-	
-	/* preserve previous backup file, needed to support autosaving */
-	GEDIT_DOCUMENT_SAVE_PRESERVE_BACKUP	= 1 << 2
-} GeditDocumentSaveFlags;
-
-
 #define GEDIT_DOCUMENT_ERROR gedit_document_error_quark ()
 
 enum
@@ -143,7 +154,11 @@ GType		 gedit_document_get_type      	(void) G_GNUC_CONST;
 
 GeditDocument   *gedit_document_new 		(void);
 
+GFile		*gedit_document_get_location	(GeditDocument       *doc);
+
 gchar		*gedit_document_get_uri 	(GeditDocument       *doc);
+void		 gedit_document_set_uri		(GeditDocument       *doc,
+						 const gchar 	     *uri);
 
 gchar		*gedit_document_get_uri_for_display
 						(GeditDocument       *doc);
@@ -230,8 +245,6 @@ gboolean	 gedit_document_get_enable_search_highlighting
 /* 
  * Non exported functions
  */
-gboolean	_gedit_document_is_saving_as	(GeditDocument       *doc);
-
 glong		 _gedit_document_get_seconds_since_last_save_or_load 
 						(GeditDocument       *doc);
 
