@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.c 6222 2008-03-22 13:52:16Z pborelli $
+ * $Id: gedit-window.c 6275 2008-05-10 09:38:26Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,7 +37,7 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gio/gio.h>
 
 #include "gedit-ui.h"
 #include "gedit-window.h"
@@ -617,6 +617,7 @@ set_sensitivity_according_to_tab (GeditWindow *window,
 	GtkAction     *action;
 	gboolean       b;
 	gboolean       state_normal;
+	gboolean       editable;
 	GeditTabState  state;
 	GtkClipboard  *clipboard;
 	GeditLockdownMask lockdown;
@@ -631,6 +632,8 @@ set_sensitivity_according_to_tab (GeditWindow *window,
 	state_normal = (state == GEDIT_TAB_STATE_NORMAL);
 
 	view = gedit_tab_get_view (tab);
+	editable = gtk_text_view_get_editable (GTK_TEXT_VIEW (view));
+
 	doc = GEDIT_DOCUMENT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
 
 	clipboard = gtk_widget_get_clipboard (GTK_WIDGET (window),
@@ -677,7 +680,7 @@ set_sensitivity_according_to_tab (GeditWindow *window,
 					      "FileClose");
 
 	gtk_action_set_sensitive (action,
-	                          (state != GEDIT_TAB_STATE_CLOSING) &&
+				  (state != GEDIT_TAB_STATE_CLOSING) &&
 				  (state != GEDIT_TAB_STATE_SAVING) &&
 				  (state != GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW) &&
 				  (state != GEDIT_TAB_STATE_PRINTING) &&
@@ -700,6 +703,7 @@ set_sensitivity_according_to_tab (GeditWindow *window,
 					      "EditCut");
 	gtk_action_set_sensitive (action,
 				  state_normal &&
+				  editable &&
 				  gtk_text_buffer_get_has_selection (GTK_TEXT_BUFFER (doc)));
 
 	action = gtk_action_group_get_action (window->priv->action_group,
@@ -711,7 +715,7 @@ set_sensitivity_according_to_tab (GeditWindow *window,
 				  
 	action = gtk_action_group_get_action (window->priv->action_group,
 					      "EditPaste");
-	if (state_normal)
+	if (state_normal && editable)
 	{
 		set_paste_sensitivity_according_to_clipboard (window,
 							      clipboard);
@@ -725,6 +729,7 @@ set_sensitivity_according_to_tab (GeditWindow *window,
 					      "EditDelete");
 	gtk_action_set_sensitive (action,
 				  state_normal &&
+				  editable &&
 				  gtk_text_buffer_get_has_selection (GTK_TEXT_BUFFER (doc)));
 
 	action = gtk_action_group_get_action (window->priv->action_group,
@@ -742,7 +747,8 @@ set_sensitivity_according_to_tab (GeditWindow *window,
 	action = gtk_action_group_get_action (window->priv->action_group,
 					      "SearchReplace");
 	gtk_action_set_sensitive (action,
-				  state_normal);
+				  state_normal &&
+				  editable);
 
 	b = gedit_document_get_can_search_again (doc);
 	action = gtk_action_group_get_action (window->priv->action_group,
@@ -776,7 +782,7 @@ set_sensitivity_according_to_tab (GeditWindow *window,
 				  gedit_prefs_manager_get_enable_syntax_highlighting ());
 
 	update_next_prev_doc_sensitivity (window, tab);
-	
+
 	gedit_plugins_engine_update_plugins_ui (gedit_plugins_engine_get_default (),
 						window, FALSE);
 }
@@ -2407,9 +2413,11 @@ selection_changed (GeditDocument *doc,
 		   GeditWindow   *window)
 {
 	GeditTab *tab;
+	GeditView *view;
 	GtkAction *action;
 	GeditTabState state;
 	gboolean state_normal;
+	gboolean editable;
 
 	gedit_debug (DEBUG_WINDOW);
 
@@ -2420,10 +2428,14 @@ selection_changed (GeditDocument *doc,
 	state = gedit_tab_get_state (tab);
 	state_normal = (state == GEDIT_TAB_STATE_NORMAL);
 
+	view = gedit_tab_get_view (tab);
+	editable = gtk_text_view_get_editable (GTK_TEXT_VIEW (view));
+
 	action = gtk_action_group_get_action (window->priv->action_group,
 					      "EditCut");
 	gtk_action_set_sensitive (action,
 				  state_normal &&
+				  editable &&
 				  gtk_text_buffer_get_has_selection (GTK_TEXT_BUFFER (doc)));
 
 	action = gtk_action_group_get_action (window->priv->action_group,
@@ -2437,6 +2449,7 @@ selection_changed (GeditDocument *doc,
 					      "EditDelete");
 	gtk_action_set_sensitive (action,
 				  state_normal &&
+				  editable &&
 				  gtk_text_buffer_get_has_selection (GTK_TEXT_BUFFER (doc)));
 }
 
@@ -3604,45 +3617,63 @@ _gedit_window_set_saving_session_state (GeditWindow *window,
 }
 
 GeditTab *
-gedit_window_get_tab_from_uri (GeditWindow *window,
-			       const gchar *uri)
+gedit_window_get_tab_from_location (GeditWindow *window,
+				    GFile       *location)
 {
 	GList *tabs;
 	GList *l;
-	
+	GeditTab *ret = NULL;
+
 	g_return_val_if_fail (GEDIT_IS_WINDOW (window), NULL);
-	g_return_val_if_fail (uri != NULL, NULL);
-	
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
+
 	tabs = gtk_container_get_children (GTK_CONTAINER (window->priv->notebook));
 	
-	l = tabs;
-	while (l != NULL)
+	for (l = tabs; l != NULL; l = g_list_next (l))
 	{
-		gchar *u;
 		GeditDocument *d;
 		GeditTab *t;
-		
+		GFile *f;
+
 		t = GEDIT_TAB (l->data);
 		d = gedit_tab_get_document (t);
 
-		u = gedit_document_get_uri (d);
+		f = gedit_document_get_location (d);
 
-		if ((u != NULL) && gnome_vfs_uris_match (uri, u))
+		if ((f != NULL))
 		{
-			g_free (u);
-			
-			g_list_free (tabs);
-			
-			return t;
+			gboolean found = g_file_equal (location, f);
+
+			g_object_unref (f);
+
+			if (found)
+			{
+				ret = t;
+				break;
+			}
 		}
-		
-		g_free (u);
-		
-		l = g_list_next (l);
 	}
 	
 	g_list_free (tabs);
 	
-	return NULL;
+	return ret;
+}
+
+/* for backward compat since it is public api */
+GeditTab *
+gedit_window_get_tab_from_uri (GeditWindow *window,
+			       const gchar *uri)
+{
+	GFile *f;
+	GeditTab *tab;
+
+	g_return_val_if_fail (GEDIT_IS_WINDOW (window), NULL);
+	g_return_val_if_fail (uri != NULL, NULL);
+
+	f = g_file_new_for_uri (uri);
+	tab = gedit_window_get_tab_from_location (window, f);
+	g_object_unref (f);
+
+	return tab;
 }
 
