@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit.c 6259 2008-05-05 09:24:33Z jessevdk $
+ * $Id: gedit.c 6269 2008-05-07 18:42:33Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -40,7 +40,6 @@
 #include <gdk/gdkx.h>
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 
 #include "gedit-app.h"
 #include "gedit-commands.h"
@@ -480,7 +479,7 @@ main (int argc, char *argv[])
 
 	gedit_debug_message (DEBUG_APP, "Create bacon connection");
 
-	connection = bacon_message_connection_new ("gedit-svn");
+	connection = bacon_message_connection_new ("gedit");
 
 	if (connection != NULL)
 	{
